# Finance tracker python CLI app<br>

### Version 1.3.0.0<br>

--added currencies conversion from Foreign Exchange Market.<br>
--added convertor for entered amount.<br>
--added input checks.<br>
--added program name title
--added delete string functionality 
--overhaul, fixes
--packed to pip